@@ -10,6 +10,7 @@ from .spatial_measure import Global_L, Local_L
 import numpy as np
 import seaborn as sns
 from matplotlib import pyplot as plt
+from pathlib import Path
 
 def load_raw(self, count_path, meta_path , visium_path):
     if os.path.exists(visium_path):
@@ -30,6 +31,7 @@ def load_raw(self, count_path, meta_path , visium_path):
             
         data = ad.AnnData(X=csr_matrix(count.values),
                                 var=var_df, obs=meta)
+        data.adata.obsm = {'spatial': meta[['x', 'y']].values.copy()}
     else:
         sys.exit("Please either provide (1) a visium path or (2) paths to count matrix and meta file.")
 
@@ -157,30 +159,64 @@ def group_adata_by_genes(self, ct_dict = None, inplace=True):
     pool_genes = data.var_names.tolist()
 
     if ct_dict is None:
-        script_dir = os.path.dirname(__file__) #<-- absolute dir the script is in
-        rel_path = ".inputs/immune_top20_markers.csv"
-        abs_file_path = os.path.join(script_dir, rel_path)
-        # ct_marker_df = pd.read_csv(abs_file_path)
-        ct_marker_df = pd.read_csv(rel_path)
-        ct_marker_df['gene'] = ct_marker_df.gene.apply(lambda x: str(x).upper())
+        ct_dict = {'B cells': ['IGKC', 'EBF1', 'BANK1', 'CD79A',
+                             'IGHD', 'IGHM', 'PAX5', 'IGLC2',
+                             'FCHSD2', 'CD79B', 'RALGPS2', 'LY6D',
+                              'MS4A1', 'MEF2C', 'IGLC3', 'BACH2', 'MAN1A',
+                               'CD55', 'BTLA', 'AFF3'],
+                    'DC': ['CD209A', 'CRIP1', 'CST3', 'CBFA2T3', 
+                            'TCF4', 'VIM', 'PID1', 'IRF8', 'FLT3',
+                             'TAGLN2', 'AHNAK', 'S100A4', 'IFI30',
+                              'LGALS1', 'CCND1', 'SYNGR2', 'H2AFY', 
+                              'BST2', 'LY6C2', 'CCDC88A'],
+                    'Macrophages': ['APOE', 'C1QB', 'C1QC', 'C1QA', 
+                                    'CCL4', 'RGS1', 'CD81', 'MS4A7',
+                                     'CTSB', 'LGMN', 'CTSS', 'SELENOP', 
+                                     'CD63', 'CD72', 'CCL3', 'CTSC', 
+                                     'TMEM176B', 'FTL1', 'ACP5', 'AIF1'], 
+                    'Monocytes': ['PLAC8', 'SLC8A1', 'FN1', 'S100A4', 
+                                    'LYZ2', 'LY6C2', 'F13A1', 'IFITM3', 
+                                    'CCR2', 'ADGRE4', 'CYBB', 'CRIP1',
+                                     'LDLRAD3', 'PID1', 'GPR141', 'LRP1',
+                                      'CCL9', 'ZEB2', 'AHNAK', 'IFITM6'], 
+                    'Neutrophils': ['S100A8', 'S100A9', 'RETNLG', 'CSF3R',
+                                     'IFITM1', 'SLPI', 'HDC', 'MMP9', 
+                                     'CXCR2', 'PBX1', 'WFDC21', 'MXD1', 
+                                     'CLEC4D', 'GDA', 'SLFN4', 'GSR',
+                                      'S100A11', 'IL1B', 'GCNT2', 'MSRB1'],
+                    'NK cells': ['GZMA', 'GZMB', 'CD7', 'CCL5', 
+                                    'NKG7', 'AW112010', 'IL2RB', 'KLRB1C', 
+                                    'KLRE1', 'KLRK1', 'CTSW', 'KLRA7', 
+                                    'KLRD1', 'NCR1', 'PRF1', 'ARSB', 
+                                    'LGALS1', 'ID2', 'CST7', 'CAR2'],
+                    'T cells': ['GM2682', 'LEF1', 'SKAP1', 'THEMIS',
+                                 'IL7R', 'ITK', 'PRKCQ', 'BCL11B',
+                                  'MS4A4B', 'CD247', 'TCF7', 'CD3E',
+                                   'CD3D', 'TRBC2', 'INPP4B', 'CD3G',
+                                    'GRAP2', 'CAMK4', 'SATB1', 'SIDT1']}
+        # script_dir = Path(__file__).parent #<-- absolute dir the script is in   
+        # file_path = (script_dir / "input/immune_top20_markers.csv").resolve()
+        # print(file_path)
+        # ct_marker_df = pd.read_csv(file_path)
+        # ct_marker_df['gene'] = ct_marker_df.gene.apply(lambda x: str(x).upper())
 
-        ct_marker_df = ct_marker_df.loc[ct_marker_df.gene.isin(pool_genes),:]
-        cts = list(set(ct_marker_df.cluster))
-        ct_dict = {}
-        for ct, gene in zip(ct_marker_df.cluster.tolist(), ct_marker_df.gene.tolist()):
-            if ct not in ct_dict.keys():
-                ct_dict[ct] = [gene]
-            else:
-                ct_dict[ct].append(gene)
-    else:
-        cts = list(ct_dict.keys())
-        if len(cts) < 2:
-            print("Please include at list 2 groups to compare against each other and call the function again.")
-            return
-        for key in ct_dict.keys():
-            vals = [v.upper() for v in ct_dict[key] if v.upper() in pool_genes]
-            ct_dict[key] = vals
-            print(f"{key}: {len(vals)} markers: {','.join(vals)}.")
+        # ct_marker_df = ct_marker_df.loc[ct_marker_df.gene.isin(pool_genes),:]
+        # cts = list(set(ct_marker_df.cluster))
+        # ct_dict = {}
+        # for ct, gene in zip(ct_marker_df.cluster.tolist(), ct_marker_df.gene.tolist()):
+        #     if ct not in ct_dict.keys():
+        #         ct_dict[ct] = [gene]
+        #     else:
+        #         ct_dict[ct].append(gene)
+    # else:
+    cts = list(ct_dict.keys())
+    if len(cts) < 2:
+        print("Please include at list 2 groups to compare against each other and call the function again.")
+        return
+    for key in ct_dict.keys():
+        vals = [v.upper() for v in ct_dict[key] if v.upper() in pool_genes]
+        ct_dict[key] = vals
+        print(f"{key}: {len(vals)} markers: {','.join(vals)}.")
     
     X = np.zeros((data.shape[0], len(cts)))
     
